function [u, v]= badTracker(I1, I2, pos)

% Number of points
k = size(pos,1);

% Size of tracking window (make it a square with odd sidelength)
winsize = 7 * [1 1];
half = floor(winsize(1)/2);

[Ir, Ic] = gradient(I1);

% Square root of a Gaussian filter
g = gauss(-half:half, 0, half/2, 1);
w = g(:) * g(:)';
w = sqrt(w(:));

for i = 1:k 
    rows = pos(i,1)+[-half:half];
    cols = pos(i,2)+[-half:half];
    
    % Stay inside the image (assumes that motion is less than 'half')
    if min(rows) < half | min(cols) < half | ...
            max(rows) > size(I1, 1) - half | max(cols) > size(I1, 2) - half
        u(i) = NaN;
        v(i) = NaN;
    else
        % Derivatives in the first frame
        Iwin = interp2(I1, cols, rows');
        r = interp2(Ir, cols, rows');
        c = interp2(Ic, cols, rows');
        
        % Left-hand side of the normal equations
        G = [w.*r(:) w.*c(:)];
        A = G'*G;
       
        % Subpixel interpolation for the second frame
        t = interp2(I2, cols, rows') - Iwin;
      
        % Right-hand side of the normal equations
        b = - w .* t(:);
        b = G' * b;
        
        % Solve A*d = b
        d = A\b;
        
        % Put the result into the output vectors
        u(i) = d(1);
        v(i) = d(2);
    end
end